#
# spec file for package xf86-video-r128
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-r128
Version:        6.12.0
Release:        bp155.2.11
Summary:        ATI Rage 128 video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.bz2
# https://lists.x.org/archives/xorg-devel/2018-June/057208.html
BuildRequires:  Mesa-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(libdrm) >= 2.2
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86driproto)
BuildRequires:  pkgconfig(xineramaproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.2
BuildRequires:  pkgconfig(xorg-server) >= 1.2
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v00001002d*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x
%x11_abi_videodrv_req

%description
r128 is an Xorg driver for ATI Rage 128 video cards.

It contains full support for 8, 15, 16 and 24 bit pixel depths, hardware
acceleration of drawing primitives, hardware cursor, video modes up to
1800x1440 @ 70Hz, doublescan modes (e.g., 320x200 and 320x240), gamma
correction at all pixel depths, a fully programming dot clock and robust
text mode restoration for VT switching. Dualhead is supported on M3/M4
mobile chips.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%doc ChangeLog README
%license COPYING
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/r128_drv.so
%{_datadir}/man/man4/r128.4%{?ext_man}

%changelog
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 6.12.0:
  * Separate EXA and XAA initialization
  * Evaluate NoAccel option inside R128PreInit
  * Evaluate EXA related options inside R128PreInit
  * Evaluate software cursor option inside R128PreInit
  * Remove OPTION_DAC_8BIT option
  * Move many DDX UMS options into R128UMSOption
  * Delete USE_CRT_ONLY conditional compilation directive
  * Delete OPTION_DISPLAY option enumeration
  * Move RAMDAC module initialization into R128LegacyMS
  * Move loading of EXA and XAA modules into R128PreInitAccel
  * Version bumped to 6.11.100
  * Prevent disabling of EXA inside R128ScreenInit
  * Consolidate frame buffer initialization code
  * Deprecate R128EXAAccelInit
  * Deprecate R128AccelInit
  * Deprecate R128VerboseInitEXA
  * Consolidate EXA initialization code into R128EXAInit
  * Hold off enabling acceleration until EXA / XAA are fully initialized
  * Version bumped to 6.11.101
  * Rename R128UMSOption to r128UMSOption
  * Consolidate acquisition of many options into two functions
  * Version bumped to 6.11.102
  * Fix for build failure when --disable-dri option is specified
  * Remove Dac6Bit option from man page
* Mon Jun 24 2019 Stefan Dirsch <sndirsch@suse.com>
- no longer require legacy extension xf86miscproto; no longer
  provided by xorgproto-2019.1 by default and never needed anyway
* Fri Jul 20 2018 sndirsch@suse.com
- Update to version 6.11.0
  * autogen.sh: Implement GNOME Build API
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
  * configure: Drop AM_MAINTAINER_MODE
  * Fix typo: Initalizing --> Initializing
  * xf86-video-r128: remove the GlxSetVisualConfigs stub and friends
  * Fix for cross build failure
  * Include <stdint.h> in order to declare uint32_t
  * Move the location where R128PreInitGamma is called
  * Move assignment of color depth variables away from R128PreInitVisual
  * Move the assignment to monitor field of ScrnInfoRec record
  * Move R128PreInitVisual and R128PreInitGamma calls
  * Remove R128ProbeDDC
  * Refactor R128PreInitWeight
  * Move the location xf86CrtcConfigInit is called inside R128PreInit
  * Move existing mode setting initialization code into R128LegacyMS
  * Move R128InitCrtcRegisters to r128_crtc.c
  * Move R128InitCrtc2Registers to r128_crtc.c
  * Move R128InitCrtcBase to r128_crtc.c
  * Move R128InitCrtc2Base to r128_crtc.c
  * Convert R128Div to an inline function
  * Move R128InitPLLRegisters to r128_crtc.c
  * Move R128InitPLL2Registers to r128_crtc.c
  * Move R128RestoreCrtcRegisters to r128_crtc.c
  * Move R128RestoreCrtc2Registers to r128_crtc.c
  * Move R128InitDACRegisters to r128_output.c
  * Move R128RestoreDACRegisters to r128_output.c
  * Move R128RestorePLLRegisters to r128_crtc.c
  * Move R128RestorePLL2Registers to r128_crtc.c
  * Move R128InitDDARegisters to r128_crtc.c
  * Move R128InitDDA2Registers to r128_crtc.c
  * Move the location R128PreInitDRI is called
  * Deprecate R128TRACE macro when generating debug messages
  * Remove compilation warnings related to debug messages
  * Using __func__ string for debug message function identification
  * Convert tabs to white spaces for r128_output.c
  * Fix for some RAGE 128 Pro causing out of range display error
  * Reorganize r128_exa.c
- supersedes u_Include-stdint.h-in-order-to-declare-uint32_t.patch
* Fri Jun 22 2018 sndirsch@suse.com
- u_Include-stdint.h-in-order-to-declare-uint32_t.patch
  * fixed build against xorg-server 1.20
- marked COPYING file correctly as %%license
* Mon May 29 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #315643-315645, 319159-319161, 319618 (bsc#1041399)
* Thu Jan 19 2017 sndirsch@suse.com
- Update to version 6.10.2
  * Adapt Block/WakeupHandler signature for ABI 23
  * Remove gatos advertisement
  * xextproto 7.1 support update to the source code
- supersedes  U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
* Wed Nov 30 2016 sndirsch@suse.com
- U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
  * Adapt Block/WakeupHandler signature for ABI 23
* Fri Jan 22 2016 sndirsch@suse.com
- Update to version 6.10.1
  * Really fix bitmasks for DDC
  * Assume CRT in the absence of other monitors
* Mon May  4 2015 sndirsch@suse.com
- Update to version 6.10.0
  * various bug fixes
- deprecates U_Only-declare-PCITAG-if-we-need-it.patch
* Fri Feb  6 2015 sndirsch@suse.com
- U_Only-declare-PCITAG-if-we-need-it.patch
  * fixes build against xorg-server 1.17
* Fri Oct 25 2013 sndirsch@suse.com
-  Update to version 6.9.2
  * this version update fixes for EXA color errors on PowerPC,
    plus updates to build with xserver 1.13 and 1.14
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sun Oct 14 2012 zaitor@opensuse.org
- Update to version 6.9.1:
  + Fix make distcheck.
  + Scale Xv with the vertical stretch ratio.
  + Remove nested preprocessor checks.
  + Fix missing preprocessor check for R128DRI.
  + Make debug mode work again.
  + Add EXA support, This introduces EXA acceleration which can
    improve performance and allow 2D acceleration to be used
    without XAA. Implemented hooks are Solid, Copy and Composite.
  + Enable EXA by default if XAA isn't available at buildtime.
* Sun Sep  2 2012 zaitor@opensuse.org
- Update to version 6.8.4:
  + Drop XAA support. This just makes XAA conditional.
- Changes since 6.8.3:
  + Port to new compat API.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 6.8.2:
  + Untangle XF86DRI from the driver-specific DRI define
  + Fix for new vgahw ABI
  + Make failure to XAA non-fatal
  + Build fix for older servers (error: conflicting types for
    'pciTag')
  + Don't allow the config file to override BIOS location
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-r128 from xorg-x11-driver-video.
  Initial version: 6.8.1.
